@@ -4,11 +4,11 @@ package Config::Simple::Conf;
 
 use strict;
 
-our $VERSION = "2.001";
+our $VERSION = "2.002";
 
 
 # Revision - cvs automagically updated
-our $REVISION = '$Id: Conf.pm,v 1.12 2016/05/25 16:06:20 cfaber Exp $';
+our $REVISION = '$Id: Conf.pm,v 1.14 2016/05/25 17:13:54 cfaber Exp $';
 
 # Ruckus Global Version Number
 
@@ -256,8 +256,6 @@ sub _fileargs {
 			# We use argv for our arguments string, and global for our global arguments,  and thus a sections named argv or global are disallowed.
 			if($hd eq 'argv'){
 				&_die("ERROR: section name [argv] is invalid and disallowed: $tfn\:$line" . ($fn ? ' included from: ' . join(' -> ', @{$fn}) : undef));
-			} elsif($hd eq 'global'){
-				&_die("ERROR: section name [global] is invalid and disallowed: $tfn\:$line" . ($fn ? ' included from: ' . join(' -> ', @{$fn}) : undef));
 			}
 
 
